RedditResponse

Type Alias RedditResponse 

pub type RedditResponse = GenericResponse<RedditTypeResponse>;
A RedditResponse the type is dynamically decided based on the kind data This is primarily used in Listing that return different type of data

Aliased Type

pub struct RedditResponse {
    pub kind: RedditDataType,
    pub data: RedditTypeResponse,
}

Fields

kind: RedditDataType

The kind value from Reddit

data: RedditTypeResponse

The Data that Reddit has responded with