pub type RedditResponse = GenericResponse<RedditTypeResponse>;Expand description
A RedditResponse the type is dynamically decided based on the kind data This is primarily used in Listing that return different type of data
Aliased Type
pub struct RedditResponse {
pub kind: RedditDataType,
pub data: RedditTypeResponse,
}Fields
kind: RedditDataTypeThe kind value from Reddit
data: RedditTypeResponseThe Data that Reddit has responded with